A brief summary of the comresp object.
# S3 method for class 'comresp'
summary(object, ...)The function returns a list with the variance components (varcomp)
and a data frame informing which genotypes had the highest DGE, the highest and
the lowest IGE, and the highest TGV. This data frame also informs the number of
aggressive, homoeostatic and sensitive. If a multi-age model was fitted, the output
list will have another data frame with the same information for each age.